# Modifications © 2020 Hashmap, Inc
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
from servz.utils.parsers.parser import Parser
from servz.utils.parsers.project_config import ProjectConfig


class ConfigParser(Parser):

    def __init__(self):
        super().__init__()
        self._path: str = ProjectConfig.config_path()

    def docker_config(self) -> dict:
        return self._config.get('docker_configuration')

